********************
Covariance functions
********************

.. currentmodule:: glimix_core.cov

.. autosummary::
  :toctree: _autosummary
  :template: class.rst

  EyeCov
  FreeFormCov
  GivenCov
  Kron2SumCov
  LinearCov
  LRFreeFormCov
  SumCov
